@@ -2,6 +2,7 @@ import logging
 import os
 from concurrent.futures import ThreadPoolExecutor, as_completed
 from datetime import datetime
+from time import sleep
 
 from .utils import SESSION, _do_output, _download_file, _get_vqd
 
@@ -11,14 +12,15 @@ logger = logging.getLogger(__name__)
 def ddg_images(
     keywords,
     region="wt-wt",
-    safesearch="Moderate",
+    safesearch="moderate",
     time=None,
     size=None,
     color=None,
     type_image=None,
     layout=None,
     license_image=None,
-    max_results=100,
+    max_results=None,
+    page=1,
     output=None,
     download=False,
 ):
@@ -27,7 +29,7 @@ def ddg_images(
     Args:
         keywords (str): keywords for query.
         region (str, optional): wt-wt, us-en, uk-en, ru-ru, etc. Defaults to "wt-wt".
-        safesearch (str, optional): On, Moderate, Off. Defaults to "Moderate".
+        safesearch (str, optional): on, moderate, off. Defaults to "moderate".
         time (Optional[str], optional): Day, Week, Month, Year. Defaults to None.
         size (Optional[str], optional): Small, Medium, Large, Wallpaper. Defaults to None.
         color (Optional[str], optional): color, Monochrome, Red, Orange, Yellow, Green, Blue,
@@ -39,8 +41,10 @@ def ddg_images(
             Share (Free to Share and Use), ShareCommercially (Free to Share and Use Commercially),
             Modify (Free to Modify, Share, and Use), ModifyCommercially (Free to Modify, Share, and
             Use Commercially). Defaults to None.
-        max_results (int, optional): maximum number of results, max=1000. Defaults to 100.
-        output (Optional[str], optional): csv, json, print. Defaults to None.
+        max_results (Optional[int], optional): maximum number of results, max=1000. Defaults to None.
+            if max_results is set, then the parameter page is not taken into account.
+        page (int, optional): page for pagination. Defaults to 1.
+        output (Optional[str], optional): csv, json. Defaults to None.
         download (bool, optional): if True, download and save images to 'keywords' folder.
             Defaults to False.
 
@@ -48,6 +52,33 @@ def ddg_images(
         Optional[List[dict]]: DuckDuckGo text search results.
     """
 
+    def get_ddg_images_page(page):
+        payload["s"] = max(PAGINATION_STEP * (page - 1), 0)
+        page_data = None
+        try:
+            resp = SESSION.get("https://duckduckgo.com/i.js", params=payload)
+            resp.raise_for_status()
+            page_data = resp.json().get("results", None)
+        except Exception:
+            logger.exception("")
+        page_results = []
+        if page_data:
+            for row in page_data:
+                if row["image"] not in cache:
+                    cache.add(row["image"])
+                    page_results.append(
+                        {
+                            "title": row["title"],
+                            "image": row["image"],
+                            "thumbnail": row["thumbnail"],
+                            "url": row["url"],
+                            "height": row["height"],
+                            "width": row["width"],
+                            "source": row["source"],
+                        }
+                    )
+        return page_results
+
     if not keywords:
         return None
 
@@ -56,9 +87,10 @@ def ddg_images(
     if not vqd:
         return None
 
-    # get images
-    safesearch_base = {"On": 1, "Moderate": 1, "Off": -1}
+    PAGINATION_STEP, MAX_API_RESULTS = 100, 1000
 
+    # prepare payload
+    safesearch_base = {"On": 1, "Moderate": 1, "Off": -1}
     time = f"time:{time}" if time else ""
     size = f"size:{size}" if size else ""
     color = f"color:{color}" if color else ""
@@ -68,50 +100,35 @@ def ddg_images(
     payload = {
         "l": region,
         "o": "json",
-        "s": 0,
+        "s": max(PAGINATION_STEP * (page - 1), 0),
         "q": keywords,
         "vqd": vqd,
         "f": f"{time},{size},{color},{type_image},{layout},{license_image}",
-        "p": safesearch_base[safesearch],
+        "p": safesearch_base[safesearch.capitalize()],
     }
 
-    results, cache = [], set()
-    while payload["s"] < min(max_results, 1000) or len(results) < max_results:
-        page_data = None
-        try:
-            resp = SESSION.get("https://duckduckgo.com/i.js", params=payload)
-            resp.raise_for_status()
-            page_data = resp.json().get("results", None)
-        except Exception:
-            logger.exception("")
-            break
-
-        if not page_data:
-            break
-
-        page_results = []
-        for row in page_data:
-            if row["image"] not in cache:
-                cache.add(row["image"])
-                result = {
-                    "title": row["title"],
-                    "image": row["image"],
-                    "thumbnail": row["thumbnail"],
-                    "url": row["url"],
-                    "height": row["height"],
-                    "width": row["width"],
-                    "source": row["source"],
-                }
-                page_results.append(result)
-        if not page_results:
-            break
-        results.extend(page_results)
-        # pagination
-        payload["s"] += 100
+    # get results
+    cache = set()
+    if max_results:
+        results = []
+        max_results = min(abs(max_results), MAX_API_RESULTS)
+        iterations = (max_results - 1) // PAGINATION_STEP + 1  # == math.ceil()
+        with ThreadPoolExecutor(min(iterations, 4)) as executor:
+            fs = []
+            for page in range(1, iterations + 1):
+                fs.append(executor.submit(get_ddg_images_page, page))
+                sleep(min(iterations / 17, 0.4))  # sleep to prevent blocking
+            for r in as_completed(fs):
+                if r.result():
+                    results.extend(r.result())
+    else:
+        results = get_ddg_images_page(page)
 
     results = results[:max_results]
+
+    # save to csv or json file
     if output:
-        _do_output(__name__, keywords, output, results)
+        _do_output("ddg_images", keywords, output, results)
 
     # download images
     if download:
@@ -132,4 +149,5 @@ def ddg_images(
                 print(f"{i}/{len(results)}")
 
         print("Done.")
+
     return results
