@@ -2,6 +2,7 @@ import logging
 from collections import deque
 from dataclasses import dataclass
 from decimal import Decimal
+from typing import Dict, Optional
 
 import requests
 
@@ -14,18 +15,18 @@ logger = logging.getLogger(__name__)
 class MapsResult:
     """Dataclass for ddg_maps search results"""
 
-    title = None
-    address = None
-    country_code = None
-    latitude = None
-    longitude = None
-    url = None
-    desc = None
-    phone = None
-    image = None
-    source = None
-    links = None
-    hours = None
+    title: Optional[str] = None
+    address: Optional[str] = None
+    country_code: Optional[str] = None
+    latitude: Optional[str] = None
+    longitude: Optional[str] = None
+    url: Optional[str] = None
+    desc: Optional[str] = None
+    phone: Optional[str] = None
+    image: Optional[str] = None
+    source: Optional[str] = None
+    links: Optional[str] = None
+    hours: Optional[Dict] = None
 
 
 def ddg_maps(
@@ -59,7 +60,7 @@ def ddg_maps(
             if latitude and longitude are set, the other parameters are not used. Defaults to None.
         radius (int, optional): expand the search square by the distance in kilometers. Defaults to 0.
         max_results (Optional[int], optional): maximum number of results. Defaults to None.
-        output (Optional[str], optional): csv, json, print. Defaults to None.
+        output (Optional[str], optional): csv, json. Defaults to None.
 
     Returns:
         Optional[List[dict]]: DuckDuckGo maps search results
@@ -195,5 +196,5 @@ def ddg_maps(
 
     results = results[:max_results]
     if output:
-        _do_output(__name__, keywords, output, results)
+        _do_output("ddg_maps", keywords, output, results)
     return results
